@@ -1,7 +1,7 @@
 package App::wdq;
 use v5.14;
 
-our $VERSION = '0.3.2';
+our $VERSION = '0.3.3';
 
 1;
 __END__
@@ -30,8 +30,8 @@ information from Wikidata or other Wikibase instances.
 
 =head1 INSTALLATION
 
-Perl should already installed at most operating systems. Otherwise [get Perl
-first](https://www.perl.org/get.html).
+Perl should already installed at most operating systems. Otherwise
+L<get Perl first|https://www.perl.org/get.html>.
 
 =head2 FROM CPAN
 
@@ -39,7 +39,7 @@ Install sources from CPAN including all dependencies:
 
   cpanm App::wdq
 
-First [install cpanm](https://github.com/miyagawa/cpanminus/#installation) if
+First L<install cpanm|https://github.com/miyagawa/cpanminus/#installation> if
 missing. If installation of C<App::wdq> fails try cpanm option C<--notest> or
 install dependencies as packages as described below.
 
